Apply the one-standard-error rule for model selection
ose_rule(tab, nse = 1)The selected model that is most parsimonious within nse standard errors of the best model
A table containing model scores
Number of standard errors to use (default: 1)
Implements the one-standard-error rule which selects the most parsimonious model within a specified number of standard errors of the best-scoring model.